
#' friendlyr

#' friendlyr
#' @param service name of the session
#' @param username username
#' @param password password
#' @keywords friendlyr
#' @export
#' @examples
#' \dontrun{
#' friendlyr()
#' }
friendlyr <- function(service, username=NULL,password=NULL){
  friendlyr_object(service = service, username, password)
}

friendlyr_object <- function(service,username, password){

  # private area

  # variables
  service_ <- service
  if (!is.null(username)){
     username_ <- username
  } else if (is.null(username)){
    username_ <-  Sys.getenv(paste0("id_",service_))
  }
  if (!is.null(password)){
     password_ <- password
  } else if (is.null(password)){
    password_ <-  Sys.getenv(paste0("pwd_",service_))
  }

  file_name <- NULL

  x <- init_request_friendly()

  get_export_name <- function(){
    return(x$exportObj$name)
  }

  get_service <- function(){
    return(service_)
  }

  filename <- function(){
    return(file_name)
  }

  # functions
  get_friendly <- function(type){
    fun <- utils::getFromNamespace(paste0(service_,"_get_",type),service_)
    return(do.call("fun",list(x=x,username=username_,password=password_)))
  }

  df_friendly <- function(type,res){
    fun <- utils::getFromNamespace(paste0(service_,"_df_",type),service_)
    return(do.call("fun",list(x=x,res=res)))
  }



  # public area
  object <- local({

    # fromDate from "2016/11/01 00:00:00"
    # toDate to "2017/05/01 00:00:00"
    # precision precision second, minute, houly, daily, monthly, yearly
    # timeResolution time resolution second, minute, houly, daily, monthly, yearly
    # element_id element_id "NO2" "O3", c(...),...
    # station_id station ids "665", c(...),...
    # COL_DATE FALSE by default: wday,YYYY,mm,dd,HH,MM,SS by default
    data <- function(fromDate=NULL,toDate=NULL,precision=NULL,timeResolution=NULL,element_id=NULL,station_id=NULL,location=NULL,COL_DATE=FALSE){

       on.exit(x <<- NULL)

       if (!is.null(station_id) && is.null(location)) {

         x <<- request_friendly(type = "data", fromDate = fromDate, toDate = toDate, precision=precision,timeResolution=timeResolution,element_id=element_id,station_id=station_id,location=NULL,COL_DATE=COL_DATE,name=get_service())
         file_name <<- get_export_name()
         x <<- request_friendly(type = "data", fromDate = fromDate, toDate = toDate, precision=precision,timeResolution=timeResolution,element_id=element_id,station_id=station_id,location=location,COL_DATE=COL_DATE,name=get_service())

       } else if (is.null(station_id) && !is.null(location)) {

          x <<- request_friendly(type = "data", fromDate = fromDate, toDate = toDate, precision=precision,timeResolution=timeResolution,element_id=element_id,station_id=NULL,location=location,COL_DATE=COL_DATE,name=get_service())
          file_name <<- get_export_name()
          meta_tmp <- get_friendly(type="meta")
          x <<- request_friendly(type = "data", fromDate = fromDate, toDate = toDate, precision=precision,timeResolution=timeResolution,element_id=element_id,station_id=as.character(unique(meta_tmp$ID)),location=NULL,COL_DATE=COL_DATE,name=get_service())
       }

       res <- df_friendly(type="data",get_friendly(type="data"))
       return(res)

    }

    qa <- function(fromDate=NULL,toDate=NULL,precision=NULL,timeResolution=NULL,element_id=NULL,station_id=NULL,location=NULL,COL_DATE=FALSE){

       on.exit(x <<- NULL)

       if (!is.null(station_id) && is.null(location)) {

         x <<- request_friendly(type = "qa", fromDate = fromDate, toDate = toDate, precision=precision,timeResolution=timeResolution,element_id=element_id,station_id=station_id,location=NULL,COL_DATE=COL_DATE,name=get_service())
         file_name <<- get_export_name()
         x <<- request_friendly(type = "qa", fromDate = fromDate, toDate = toDate, precision=precision,timeResolution=timeResolution,element_id=element_id,station_id=station_id,location=location,COL_DATE=COL_DATE,name=get_service())

       } else if (is.null(station_id) && !is.null(location)) {

          x <<- request_friendly(type = "qa", fromDate = fromDate, toDate = toDate, precision=precision,timeResolution=timeResolution,element_id=element_id,station_id=NULL,location=location,COL_DATE=COL_DATE,name=get_service())
          file_name <<- get_export_name()
          meta_tmp <- get_friendly(type="meta")
          x <<- request_friendly(type = "qa", fromDate = fromDate, toDate = toDate, precision=precision,timeResolution=timeResolution,element_id=element_id,station_id=as.character(unique(meta_tmp$ID)),location=NULL,COL_DATE=COL_DATE,name=get_service())
       }

       res <- df_friendly(type="qa",get_friendly(type="qa"))
       return(res)

    }

    meta <- function(element_id=NULL,timeResolution=NULL,station_id=NULL,location=NULL){

      on.exit(x <<- NULL)
      x <<- request_friendly(type="meta",element_id=element_id,timeResolution=timeResolution,station_id=station_id,location=location)
      res <- get_friendly(type="meta")
      return(res)

    }

    name <- function(){

      res <- filename()
      return(res)

    }

    summary <- function(){
      res <- paste0("Make timeseries dataframe from ",name," easier to get and manipulate with")
    }


    environment()
    })
    lockEnvironment(object, TRUE)
    structure(object, class=c("friendlyr", class(object)))
}
