init_request_friendly <- function(){
  x <- list(timeObj=NULL,elementObj=NULL,stationObj=NULL,dateStructObj=NULL,exportObj=NULL)
  class(x) <- c("request_friendly",class(x))
  return(x)
}

request_friendly <- function(type=NULL, fromDate=NULL,toDate=NULL,precision=NULL,timeResolution=NULL,element_id=NULL,station_id=NULL,location=NULL,COL_DATE=FALSE,name=NULL){

  name <- as.character(name)

  name          <- switch(type,"data" = paste0(name,"_data"), "qa" = paste0(name,"_qa"), "meta" = paste0(name,"_meta_"), stop("type of request not recognized"))
  timeObj       <- request_timeObj(fromDate=fromDate,toDate=toDate,precision=precision,timeResolution=timeResolution)
  elementObj    <- request_elementObj(element_id = element_id)
  stationObj    <- request_stationObj(station_id = station_id, location = location)
  dateStructObj <- switch(type,"data" = request_dateStructObj(COL_DATE = COL_DATE), "qa" = request_dateStructObj(COL_DATE = COL_DATE), "meta" =NULL, stop("type of request not recognized"))
  exportObj     <- request_exportObj(name=name,timeObj=timeObj,stationObj=stationObj,elementObj=elementObj)

  x <- list(timeObj=timeObj,elementObj=elementObj,stationObj=stationObj,dateStructObj=dateStructObj,exportObj=exportObj)

  class(x) <- c("request_friendly",class(x))
  return(x)
}

request_timeObj <- function(fromDate=NULL,toDate=NULL,precision=NULL,timeResolution=NULL){
  if (!is.null(timeResolution)){
    if (!is.null(fromDate) && !is.null(toDate)) {
      res <- timemanip::timemanip(fromPeriod = timemanip::YYYYmmddHHMMSS(timemanip::YYYYmmddHHMMSS2_chr(as.character(fromDate))),
                                      toPeriod = timemanip::YYYYmmddHHMMSS(timemanip::YYYYmmddHHMMSS2_chr(as.character(toDate))),
                                      timeResolution = as.character(timeResolution),
                                      precision = as.character(precision))
    } else if (is.null(fromDate) && is.null(toDate)){
      res <- timemanip::timemanip(fromPeriod = NULL,
                                      toPeriod = NULL,
                                      timeResolution = as.character(timeResolution),
                                      precision = as.character(precision))
    } else stop("fromDate and to Date must be both either null or non-null")
  } else if (is.null(timeResolution)) {
    res <- timemanip::timemanip(fromPeriod = NULL,
                                toPeriod = NULL,
                                timeResolution = NULL,
                                precision = NULL)
  } else stop("timeResolution muste either null or not null")

  return(res)

}

request_elementObj <- function(element_id = NULL){
  return(list(element_id = as.character(element_id)))

}

request_stationObj <- function(station_id=NULL,location=NULL){
  if (is.null(station_id) && !is.null(location)) {

    if(is.character(location)) {
      bbox_ <- osmdata::getbb(location)
      dim(bbox_) <- NULL
      west <- bbox_[1]
      south <- bbox_[2]
      east <- bbox_[3]
      north <- bbox_[4]
    } else if (is.numeric(location) && (length(location)==4)) {
      west <- location[1]
      south <- location[2]
      east <- location[3]
      north <- location[4]
    } else stop("location not recognized")

    res <- list(station_id = NULL, west=west,south=south,east=east,north=north)

  } else if (!is.null(station_id) && is.null(location)) {
     res <- list(station_id = as.character(station_id), west=NULL,south=NULL,east=NULL,north=NULL)
  } else if (is.null(station_id) && is.null(location)) {
    res <- list(station_id = NULL, west=NULL,south=NULL,east=NULL,north=NULL)
  } else stop("args not recognized")

  return(res)
}

request_dateStructObj <-function(COL_DATE=FALSE){
  if (is.logical(COL_DATE)) {
     res <- list(COL_DATE = as.logical(COL_DATE))
  } else stop("COL_DATE must be logical")
  return(res)
}

request_exportObj <- function(name=NULL,timeObj=NULL,stationObj=NULL,elementObj=NULL){
  if (!is.null(timeObj)) {
    if (!is.null(stationObj$station_id) && !is.null(elementObj$element_id)) {
       name <- paste0(as.character(name),"_",timeObj$fromPeriod(),"_",timeObj$toPeriod(),"_",paste(stationObj$station_id,collapse="_"),"_",paste(elementObj$element_id,collapse="_"))
    } else if ((!is.null(stationObj$west) && !is.null(stationObj$south) && !is.null(stationObj$east) && !is.null(stationObj$north)) && !is.null(elementObj$element_id)) {
       name <- paste0(
                  as.character(name),"_",timeObj$fromPeriod(),"_",timeObj$toPeriod(),"_",
                  paste(stationObj$west,stationObj$south,stationObj$east,stationObj$north,sep="_"),"_",
                  paste(elementObj$element_id,collapse="_")
               )

   } else stop("missing args in stationObj")
 } else if (is.null(timeObj)) {
   if (!is.null(stationObj$station_id) && !is.null(elementObj$element_id)) {
      name <- paste0(as.character(name),"_",paste(stationObj$station_id,collapse="_"),"_",paste(elementObj$element_id,collapse="_"))
   } else if ((!is.null(stationObj$west) && !is.null(stationObj$south) && !is.null(stationObj$east) && !is.null(stationObj$north)) && !is.null(elementObj$element_id)) {
      name <- paste0(
                 as.character(name),"_",
                 paste(stationObj$west,stationObj$south,stationObj$east,stationObj$north,sep="_"),"_",
                 paste(elementObj$element_id,collapse="_"))

  } else stop("missing args in stationObj")

 } else stop("timeObj not recognized")
 res <- list(name = name)
 return(res)
}
