
#' as_tbl_friendlyts

#' as_tbl_friendlyts
#' @param df data.frame
#' @param precision precision
#' @param date_col date_col
#' @param date_type date_type
#' @param tzone tzone
#' @param CHECKNAS boolean take out columns with NAs only
#' @keywords friendlyts
#' @export
#' @examples
#' \dontrun{
#' as_tbl_friendlyts()
#' }
as_tbl_friendlyts <- function(df,precision=NULL,date_col=NULL,date_type=c("friendlyts","posixlt","df_yymmdd_hhmmss","%Y-%m-%d %H:%M:%S","%Y-%m-%dT%H:%M:%OSZ","%Y/%m/%d %H:%M:%S"),tzone="UTC",CHECKNAS=TRUE){

  date_type <- match.arg(date_type)

  if (!inherits(df,"data.frame")) stop("df need to be at least a data.frame")

  if ((is.null(date_col)) && ((!is.null(precision)) && (date_type=="friendlyts"))) {

    warning_structure(names_df=colnames(df),precision=precision)

  }

  if (((date_type == "posixlt") || (date_type == "%Y-%m-%d %H:%M:%S") || (date_type == "%Y-%m-%dT%H:%M:%OSZ")  || (date_type == "%Y/%m/%d %H:%M:%S")) && (is.null(precision))) {
    precision <- "second"
  } else {
     if (is.null(precision)) stop("Need to know the precision")
  }

  if (!inherits(df,"tbl_friendlyts")) {

    res <- as_tbl_friendlyts_(df=df,date_col=date_col,precision=precision,date_type=date_type,tzone=tzone,CHECKNAS=CHECKNAS)

    return(res)

  } else {
     return(df)
  }
}




as_tbl_friendlyts_ <- function(df,date_col=NULL,precision,date_type=c("friendlyts","posixlt","df_yymmdd_hhmmss","%Y-%m-%d %H:%M:%S","%Y-%m-%dT%H:%M:%OSZ","%Y/%m/%d %H:%M:%S"),tzone="UTC",CHECKNAS=TRUE){


  # extract date and colnames
  if ((date_type != "friendlyts") && (!is.null(date_col))) {
    dateTS <- timemanip::foo2_yymmdd_hhmmss(as.data.frame(df)[,date_col],precision=precision,tz=tzone,type=date_type)
    non_date_col <- setdiff(names(df), date_col)
  } else if (date_type == "friendlyts") {
    dateTS <- fts_yymmdd_hhmmss(df,precision=precision,tzone=tzone)
    date_col <- get_date_col(precision=precision)
    non_date_col <- setdiff(names(df), names(df)[date_col])
  } else stop("date_col required.")

  names(df)    <- gsub("\\.","_",names(df))
  date_col     <- gsub("\\.","_",date_col)
  non_date_col <- gsub("\\.","_",non_date_col)

  if (length(non_date_col)>0) {
    value <- df[,non_date_col]
  } else {
    value <- rep(NA,length(as.POSIXlt(dateTS)))
    non_date_col <- "empty"
    CHECKNAS <- FALSE
  }

  res <- data.frame(
         WDAY = timemanip::wday(as.POSIXlt(dateTS)),
         date = switch(precision,
           "yearly"  = timemanip::YYYY_m(as.POSIXlt(dateTS)),
           "monthly" = timemanip::YYYYmm_m(as.POSIXlt(dateTS)),
           "daily"   = timemanip::YYYYmmdd_m(as.POSIXlt(dateTS)),
           "hourly"  = timemanip::YYYYmmddHH_m(as.POSIXlt(dateTS)),
           "minute"  = timemanip::YYYYmmddHHMM_m(as.POSIXlt(dateTS)),
           "second"  = timemanip::YYYYmmddHHMMSS_m(as.POSIXlt(dateTS)),
           stop("precision not recognized")),
         value = value)

  colname_date <- get_name_date_col(precision)
  colnames(res) <- c(colname_date,non_date_col)

  if (CHECKNAS){
    # taking out empty columns
    icol <- get_non_date_col(precision=precision)
    indice <- c()
    for (i in icol:ncol(res)){
      BOOL <- length(which(is.na(res[,i])))==nrow(res)
      if (BOOL) {
        indice <- c(indice,i)
      }
    }
    if (length(indice)>0) {
      print(paste0("Because made only of NAs, the following columns are taken away: ",paste0(names(df)[indice],collapse=",")))
      res <- res[,-indice]

      non_date_col <- setdiff(names(res), names(res)[date_col])
      if (length(non_date_col)==0) {
        value <- rep(NA,length(as.POSIXlt(dateTS)))
        non_date_col <- "empty"
        res <- data.frame(
               WDAY = timemanip::wday(as.POSIXlt(dateTS)),
               date = switch(precision,
                 "yearly"  = timemanip::YYYY_m(as.POSIXlt(dateTS)),
                 "monthly" = timemanip::YYYYmm_m(as.POSIXlt(dateTS)),
                 "daily"   = timemanip::YYYYmmdd_m(as.POSIXlt(dateTS)),
                 "hourly"  = timemanip::YYYYmmddHH_m(as.POSIXlt(dateTS)),
                 "minute"  = timemanip::YYYYmmddHHMM_m(as.POSIXlt(dateTS)),
                 "second"  = timemanip::YYYYmmddHHMMSS_m(as.POSIXlt(dateTS)),
                 stop("precision not recognized")),
               value = value)
         colname_date <- get_name_date_col(precision)
         colnames(res) <- c(colname_date,non_date_col)

      }
    }
  }

  # time related colums as integer and sort
  if (precision == "yearly") {
    res$WDAY  <- as.integer(as.character(res$WDAY))
    res$YEAR  <- as.integer(as.character(res$YEAR))
    res <- res %>% arrange(YEAR)
    res$WDAY  <- as.factor(res$WDAY)
    res$YEAR  <- as.factor(res$YEAR)
  }
  if (precision == "monthly") {
    res$WDAY  <- as.integer(as.character(res$WDAY))
    res$YEAR  <- as.integer(as.character(res$YEAR))
    res$MONTH <- as.integer(as.character(res$MONTH))
    res <- res %>% arrange(YEAR,MONTH)
    res$WDAY  <- as.factor(res$WDAY)
    res$YEAR  <- as.factor(res$YEAR)
    res$MONTH <- as.factor(res$MONTH)
  }
  if (precision == "daily") {
    res$WDAY  <- as.integer(as.character(res$WDAY))
    res$YEAR  <- as.integer(as.character(res$YEAR))
    res$MONTH <- as.integer(as.character(res$MONTH))
    res$DAY   <- as.integer(as.character(res$DAY))
    res <- res %>% arrange(YEAR,MONTH,DAY)
    res$WDAY  <- as.factor(res$WDAY)
    res$YEAR  <- as.factor(res$YEAR)
    res$MONTH <- as.factor(res$MONTH)
    res$DAY   <- as.factor(res$DAY)
  }
  if (precision == "hourly") {
    res$WDAY  <- as.integer(as.character(res$WDAY))
    res$YEAR  <- as.integer(as.character(res$YEAR))
    res$MONTH <- as.integer(as.character(res$MONTH))
    res$DAY   <- as.integer(as.character(res$DAY))
    res$HOUR  <- as.integer(as.character(res$HOUR))
    res <- res %>% arrange(YEAR,MONTH,DAY,HOUR)
    res$WDAY  <- as.factor(res$WDAY)
    res$YEAR  <- as.factor(res$YEAR)
    res$MONTH <- as.factor(res$MONTH)
    res$DAY   <- as.factor(res$DAY)
    res$HOUR  <- as.factor(res$HOUR)
  }
  if (precision == "minute") {
    res$WDAY  <- as.integer(as.character(res$WDAY))
    res$YEAR  <- as.integer(as.character(res$YEAR))
    res$MONTH <- as.integer(as.character(res$MONTH))
    res$DAY   <- as.integer(as.character(res$DAY))
    res$HOUR  <- as.integer(as.character(res$HOUR))
    res$MINUTE  <- as.integer(as.character(res$MINUTE))
    res <- res %>% arrange(YEAR,MONTH,DAY,HOUR,MINUTE)
    res$WDAY  <- as.factor(res$WDAY)
    res$YEAR  <- as.factor(res$YEAR)
    res$MONTH <- as.factor(res$MONTH)
    res$DAY   <- as.factor(res$DAY)
    res$HOUR  <- as.factor(res$HOUR)
    res$MINUTE  <- as.factor(res$MINUTE)
  }
  if (precision == "second") {
    res$WDAY  <- as.integer(as.character(res$WDAY))
    res$YEAR  <- as.integer(as.character(res$YEAR))
    res$MONTH <- as.integer(as.character(res$MONTH))
    res$DAY   <- as.integer(as.character(res$DAY))
    res$HOUR  <- as.integer(as.character(res$HOUR))
    res$MINUTE  <- as.integer(as.character(res$MINUTE))
    res$SECOND  <- as.integer(as.character(res$SECOND))
    res <- res %>% arrange(YEAR,MONTH,DAY,HOUR,MINUTE,SECOND)
    res$WDAY  <- as.factor(res$WDAY)
    res$YEAR  <- as.factor(res$YEAR)
    res$MONTH <- as.factor(res$MONTH)
    res$DAY   <- as.factor(res$DAY)
    res$HOUR  <- as.factor(res$HOUR)
    res$MINUTE  <- as.factor(res$MINUTE)
    res$SECOND  <- as.factor(res$SECOND)
  }


  class(res) <- c("tbl_friendlyts", class(res))
  return(res)
}
