#' check_date

#' check_date
#' @param tbl_fts friendlyts tbl
#' @param fromDate from "2016/11/01 00:00:00"
#' @param toDate to "2017/05/01 00:00:00"
#' @param timeResolution timeResolution
#' @param v v
#' @param precision precision
#' @param tzone tzone
#' @param missingValues missingValues
#' @param date_type date_type
#' @keywords friendlyr
#' @export
#' @examples
#' \dontrun{
#' check_date()
#' }
check_date <- function(tbl_fts, fromDate,toDate,timeResolution, v=1, precision, tzone="UTC",missingValues=NA,date_type=c("friendlyts","posixlt","df_yymmdd_hhmmss","%Y-%m-%d %H:%M:%S","%Y-%m-%dT%H:%M:%OSZ","%Y/%m/%d %H:%M:%S")){


  if (!inherits(tbl_fts,"tbl_friendlyts")) stop("tbl_fts must be friendlyts")

  # extract date
  if (date_type != "friendlyts") {
    fromDate <- timemanip::foo2_yymmdd_hhmmss(fromDate,precision=precision,tz=tzone,type=date_type)
    toDate <- timemanip::foo2_yymmdd_hhmmss(toDate,precision=precision,tz=tzone,type=date_type)
  } else {
    fromDate <- fts_yymmdd_hhmmss(fromDate,precision=precision,tzone=tzone)
    toDate <- fts_yymmdd_hhmmss(toDate,precision=precision,tzone=tzone)
  }

  # build a POSIXlt vector of from the data
  if (!is.null(tbl_fts)) {



     # extract date timeserie
     uncompleteTS <- fts_yymmdd_hhmmss(tbl_fts=tbl_fts,precision=precision,tzone=tzone)
     nbstep <- length(uncompleteTS)

     # get name of the columns
     date_col <- get_date_col(precision=precision)
     non_date_col <- setdiff(names(tbl_fts), names(tbl_fts)[date_col])

     # build continuous timeserie
     if (length(non_date_col)>0){


       # build continuous date timeserie
       timeObj <- timemanip::timemanip(fromPeriod = timemanip::YYYYmmddHHMMSS(fromDate),
                                       toPeriod = timemanip::YYYYmmddHHMMSS(toDate),
                                       timeResolution = as.character(timeResolution),
                                       v=v,
                                       precision = as.character(precision))

       # match between complete and non-complete date timeserie
       indice <- match(as.POSIXct(uncompleteTS),as.POSIXct(timeObj$seqPeriod()))

       if (length(indice)>0){

         is_not_na <- which(!is.na(indice))

         # build new friendlyts table
         res <- new_tbl_friendlyts(fromDate=fromDate,toDate=toDate,timeResolution=timeResolution,v=v,precision=precision,tzone=tzone,varnames=non_date_col,date_type="posixlt")
         #inject values
         res[indice[is_not_na],non_date_col] <- tbl_fts[is_not_na,non_date_col]

       } else {
         #
       }


     } else {
       #build an empty result
      res <- new_tbl_friendlyts(fromDate=fromDate,toDate=toDate,timeResolution=timeResolution,v=v,precision=precision,tzone=tzone,varnames="empty",date_type="posixlt")

     }

     return(res)


  } else stop("tbl_fts is NULL")

 }
