
#' new_tbl_friendlyts
#' @param fromDate from "2016/11/01 00:00:00"
#' @param toDate to "2017/05/01 00:00:00"
#' @param timeResolution "daily","hourly","minute","second",...
#' @param v multiplicative coefficient to the timeResolution
#' @param precision "daily","hourly","minute","second",...
#' @param tzone time zone "UTC"
#' @param varnames name of the variables
#' @param missingValues missingValues
#' @param date_type date_type
#' @keywords friendlyts
#' @export
#' @examples
#' \dontrun{
#' new_tbl_friendlyts()
#' }
new_tbl_friendlyts <- function(fromDate,toDate,timeResolution,v=1,precision=NULL,tzone="UTC",varnames,missingValues=NA,date_type=c("friendlyts","posixlt","df_yymmdd_hhmmss","%Y-%m-%d %H:%M:%S","%Y-%m-%dT%H:%M:%OSZ","%Y/%m/%d %H:%M:%S")){

  # extract date
  if (date_type != "friendlyts") {
    fromDate <- timemanip::foo2_yymmdd_hhmmss(fromDate,precision=precision,tz=tzone,type=date_type)
    toDate <- timemanip::foo2_yymmdd_hhmmss(toDate,precision=precision,tz=tzone,type=date_type)
  } else {
    fromDate <- fts_yymmdd_hhmmss(fromDate,precision=precision,tzone=tzone)
    toDate <- fts_yymmdd_hhmmss(toDate,precision=precision,tzone=tzone)
  }

  timeObj <- timemanip::timemanip(fromPeriod = timemanip::YYYYmmddHHMMSS(fromDate),
                                  toPeriod = timemanip::YYYYmmddHHMMSS(toDate),
                                  timeResolution = as.character(timeResolution),
                                  precision = as.character(precision),
                                  v = v,
                                  tzone = tzone)

  nc <- length(varnames)
  if (!length(nc)) stop("varnames must be at least of length 1")

  df <- data.frame(
         date = as.POSIXlt(timeObj$seqPeriod()),
         value = as.data.frame(stats::setNames(replicate(length(varnames),rep(missingValues,timeObj$nbStep()), simplify = F), varnames)))
  colnames(df) <-c("date",varnames)

  res <- as_tbl_friendlyts_(df=df,date_col="date",precision=precision,date_type="posixlt",tzone=tzone,CHECKNAS=FALSE)

  return(res)

}
