#' @importFrom dplyr %>% bind_cols select select_ filter filter_ mutate mutate_ transmute transmute_ group_by group_by_ arrange
NULL

#' file_friendlyts

#' file_friendlyts
#' @param name name
#' @param format format
#' @keywords friendlyts
#' @export
#' @examples
#' \dontrun{
#' file_friendlyts()
#' }
file_friendlyts <- function(name=NULL,format){
  res <- file_path(filePath=tempdir(),subF="friendlyts",name=name,format=format)
  return(res)
}

file_path <- function(filePath,subF,name=NULL,format=format){
  filedir <- normalizePath(file.path(filePath,subF),mustWork = FALSE)
  dir.create(filedir, showWarnings = FALSE, recursive = TRUE)
  if(is.null(name)) {
    res <- normalizePath(tempfile(pattern = "file", tmpdir = filedir, fileext = paste0(".",format)),mustWork = FALSE)
  } else res <- normalizePath(file.path(filedir,paste0(name,".",format)),mustWork = FALSE)
  return(res)
}

warning_structure <- function(names_df,precision){
  switch(precision,
     "yearly"  = if (prod(!( (names_df[1:2]==c("WDAY","YEAR"))  ))==1) stop("structure of df should respect colnames: WDAY, YEAR, ..."),
     "monthly" = if (prod(!( (names_df[1:3]==c("WDAY","YEAR","MONTH"))  ))==1) stop("structure of df should respect colnames: WDAY, YEAR, MONTH, ..."),
     "daily"   = if (prod(!( (names_df[1:4]==c("WDAY","YEAR","MONTH","DAY"))  ))==1) stop("structure of df should respect colnames: WDAY, YEAR, MONTH, DAY, ..."),
     "hourly"  = if (prod(!( (names_df[1:5]==c("WDAY","YEAR","MONTH","DAY","HOUR"))  ))==1) stop("structure of df should respect colnames: WDAY, YEAR, MONTH, DAY, HOUR ..."),
     "minute"  = if (prod(!( (names_df[1:6]==c("WDAY","YEAR","MONTH","DAY","HOUR","MINUTE"))  ))==1) stop("structure of df should respect colnames: WDAY, YEAR, MONTH, DAY, HOUR, MINUTE ..."),
     "second"  = if (prod(!( (names_df[1:7]==c("WDAY","YEAR","MONTH","DAY","HOUR","MINUTE","SECOND"))  ))==1) stop("structure of df should respect colnames: WDAY, YEAR, MONTH, DAY, HOUR, MINUTE,SECOND, ..."),
     stop("precision not yet taken into account"))
}


#' get_date_col

#' get_date_col
#' @param precision precision
#' @keywords friendlyts
#' @export
#' @examples
#' \dontrun{
#' get_date_col()
#' }
get_date_col <- function(precision){

 res <- switch(precision,
    "yearly"  = c(1:2),
    "monthly" = c(1:3),
    "daily"   = c(1:4),
    "hourly"  = c(1:5),
    "minute"  = c(1:6),
    "second"  = c(1:7),
    stop("precision not yet taken into account"))

 return(res)
}

#' get_non_date_col

#' get_non_date_col
#' @param precision precision
#' @keywords friendlyts
#' @export
#' @examples
#' \dontrun{
#' get_non_date_col()
#' }
get_non_date_col <- function(precision){

 res <- switch(precision,
    "yearly"  = 3,
    "monthly" = 4,
    "daily"   = 5,
    "hourly"  = 6,
    "minute"  = 7,
    "second"  = 8,
    stop("precision not yet taken into account"))

 return(res)
}

#' get_name_date_col

#' get_name_date_col
#' @param precision precision
#' @keywords friendlyts
#' @export
#' @examples
#' \dontrun{
#' get_name_date_col()
#' }
get_name_date_col <- function(precision){
  res <- switch(precision,
      "yearly"  = "YEAR",
      "monthly" = c("YEAR","MONTH"),
      "daily"   = c("YEAR","MONTH","DAY"),
      "hourly"  = c("YEAR","MONTH","DAY","HOUR"),
      "minute"  = c("YEAR","MONTH","DAY","HOUR","MINUTE"),
      "second"  = c("YEAR","MONTH","DAY","HOUR","MINUTE","SECOND"),
      stop("precision not recognized"))

  res <-c("WDAY",res)
  return(res)
}

setnames <- function (object = name, name) {
    names(object) <- name
    return(object)
}
