#' timemanip
#'
#' timemanip
#'
#' @param fromPeriod dateChr "YYYYmmddHH..."
#' @param toPeriod dateChr "YYYYmmddHH..."
#' @param timeResolution "daily","hourly","minute","second",...
#' @param v multiplicative coefficient to the timeResolution
#' @param precision "daily","hourly","minute","second",...
#' @param tzone time zone
#' @keywords timemanip
#' @export
#' @examples
#' res <- timemanip(fromPeriod="2013060205",toPeriod="2013060205",
#'                  v=1,timeResolution="hourly",precision="hourly")
#' res$seqPeriod()
timemanip  <- function(fromPeriod=NULL,toPeriod=NULL,timeResolution=NULL,v=1,precision=NULL,tzone="UTC"){
   timemanip_object(I_fromPeriod=fromPeriod,I_toPeriod=toPeriod,I_timeResolution=timeResolution,I_v=v,I_precision=precision,I_tzone=tzone)
}

timemanip_object <- function(I_fromPeriod,I_toPeriod,I_timeResolution,I_v,I_precision,I_tzone){

  if (!is.null(I_timeResolution)) {
     trinsec <- insec(timeResolution=I_timeResolution)
  } else if (is.null(I_timeResolution)) trinsec <- NULL

  if (is.null(I_precision)) {
    p_precision <- I_timeResolution
  } else if (!is.null(I_precision)) p_precision <- I_precision

  p_fromPeriod   <- NULL
  p_toPeriod     <- NULL
  p_fromDateTime <- NULL
  p_toDateTime   <- NULL
  FUN            <- function(...){NULL}
  p_tzone <- I_tzone

  if (!is.null(I_fromPeriod)) {
    p_fromPeriod <- timemanip::YYYYmmddHHMMSS(standard(precision=p_precision, I_fromPeriod))
    p_fromDateTime <- timemanip::standard(precision=p_precision, I_fromPeriod)
  }
  if (!is.null(I_toPeriod)) {
    p_toPeriod <- timemanip::YYYYmmddHHMMSS(standard(precision=p_precision, I_toPeriod))
    p_toDateTime <- timemanip::standard(precision=p_precision, I_toPeriod)
  }

  if (!is.null(I_fromPeriod) && !is.null(I_toPeriod)) {
    FUN <- getFromNamespace(x="timeserie", ns="timemanip")
  }

  object <- local({

     fromPeriod <- function(){
       return(p_fromPeriod)
     }

     toPeriod <- function(){
       return(p_toPeriod)
     }

     fromDateTime <- function(){
       return(p_fromDateTime)
     }

     toDateTime <- function(){
       return(p_toDateTime)
     }

     timeResolution <- function(){
       return(I_timeResolution)
     }

     v <- function(){
       return(I_v)
     }

     precision <- function(){
       return(p_precision)
     }

     Timeresinsec <- function(){
       return(trinsec)
     }

     tzone <- function(){
       return(p_tzone)
     }

     nbStep <- function(){
       return(FUN(timeResolution=I_timeResolution,v=I_v,fromPeriod=p_fromPeriod,toPeriod=p_toPeriod,precision=p_precision,tzone=p_tzone)$nbStep)
     }

     seqPeriod <- function(i=NULL){
       if (is.null(i)) {
         return(FUN(timeResolution=I_timeResolution,v=I_v,fromPeriod=p_fromPeriod,toPeriod=p_toPeriod,precision=p_precision,tzone=p_tzone)$seqPeriod)
       } else return(FUN(timeResolution=I_timeResolution,v=I_v,fromPeriod=p_fromPeriod,toPeriod=p_toPeriod,precision=p_precision,tzone=p_tzone)$seqPeriod[i])
     }

     convertTZ <- function(toTZ) {
       p_fromDateTime <<- timemanip::convertzone(ts=p_fromDateTime,fromtzone=p_tzone,totzone=toTZ)
       p_toDateTime <<- timemanip::convertzone(ts=p_toDateTime,fromtzone=p_tzone,totzone=toTZ)
       p_tzone <<- toTZ
       invisible()
     }

     summary <- function(){
       res <- list(fromPeriod = p_fromPeriod,
                   toPeriod   = p_toPeriod,
                   fromDateTime = p_fromDateTime,
                   toDateTime = p_toDateTime,
                   timeResolution = I_timeResolution,
                   v = I_v,
                   precision =    p_precision,
                   timeresinsec = trinsec,
                   tzone =  p_tzone)
      return(res)
     }


     environment()
   })
   lockEnvironment(object, TRUE)
   structure(object, class=c("timemanip", class(object)))

}
